Struct libp2p_identify::Identify[][src]

pub struct Identify { /* fields omitted */ }

Network behaviour that automatically identifies nodes periodically, returns information about them, and answers identify queries from other nodes.

Implementations

impl Identify[src]

pub fn new(
    protocol_version: String,
    agent_version: String,
    local_public_key: PublicKey
) -> Self
[src]

Creates a new Identify network behaviour.